==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/id.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Sandi kunci pemuliahan tidak ada",
    "Please repeat the recovery key password" : "Silakan ulangi sandi kunci pemulihan",
    "Repeated recovery key password does not match the provided recovery key password" : "Sandi kunci pemulihan yang diulangi tidak cocok dengan sandi kunci pemulihan yang diberikan",
    "Recovery key successfully enabled" : "Kunci pemulihan berhasil diaktifkan",
    "Could not enable recovery key. Please check your recovery key password!" : "Tidak dapat mengaktifkan kunci pemulihan. Silakan periksa sandi kunci pemulihan Anda!",
    "Recovery key successfully disabled" : "Kunci pemulihan berhasil dinonaktifkan",
    "Could not disable recovery key. Please check your recovery key password!" : "Tidak dapat menonaktifkan kunci pemulihan. Silakan periksa sandi kunci pemulihan Anda!",
    "Missing parameters" : "Parameter salah",
    "Please provide the old recovery password" : "Mohon berikan sandi pemulihan lama",
    "Please provide a new recovery password" : "Mohon berikan sandi pemulihan baru",
    "Please repeat the new recovery password" : "Silakan ulangi sandi pemulihan baru",
    "Password successfully changed." : "Sandi berhasil diubah",
    "Could not change the password. Maybe the old password was not correct." : "Tidak dapat mengubah sandi. Kemungkinan sandi lama yang dimasukkan salah.",
    "Recovery Key disabled" : "Kunci Pemulihan dinonaktifkan",
    "Recovery Key enabled" : "Kunci Pemulihan diaktifkan",
    "Could not enable the recovery key, please try again or contact your administrator" : "Tidak dapat mengaktifkan kunci pemulihan, silakan coba lagi atau hubungi administrator Anda",
    "Could not update the private key password." : "Tidak dapat memperbarui sandi kunci private.",
    "The old password was not correct, please try again." : "Sandi lama salah, mohon coba lagi.",
    "The current log-in password was not correct, please try again." : "Sandi masuk saat ini salah, mohon coba lagi.",
    "Private key password successfully updated." : "Sandi kunci privat berhasil diperbarui.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Anda perlu mengganti kunci enkripsi Anda dari enkripsi lama (ownCloud <= 8.0) ke yang baru. Mohon jalankan 'occ encryption:migrate' atau hubungi administrator Anda",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Kunci privat tidak sah untuk aplikasi enkripsi. Silakan perbarui sandi kunci privat anda pada pengaturan pribadi untuk memulihkan akses ke berkas anda yang dienkripsi.",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikasi enkripsi telah diaktifkan tetapi kunci tidak terinisialisasi, silakan log-out dan log-in lagi",
    "Encryption app is enabled and ready" : "Apl enkripsi aktif dan siap",
    "Bad Signature" : "Tanda salah",
    "Missing Signature" : "Tanda hilang",
    "one-time password for server-side-encryption" : "Sandi sekali pakai untuk server-side-encryption",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tidak dapat mendekripsi berkas ini, mungkin ini adalah berkas bersama. Silakan meminta pemilik berkas ini untuk membagikan kembali dengan Anda.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tidak dapat membaca berkas ini, kemungkinan merupakan berkas berbagi. Silakan minta pemilik berkas untuk membagikan ulang kepada Anda.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hai,\n\nadmin mengaktifkan server-side-encryption. Berkas-berkas Anda dienkripsi menggunakan sandi '%s'.\n\nSilakan masuk di antarmuka web, pergi ke bagian 'modul enkripsi dasar' pada pengaturan pribadi Anda dan perbarui sandi enkripsi Anda dengan memasukkan sandi ini kedalam kolom 'sandi masuk yang lama' dan sandi-masuk saat ini.\n\n",
    "The share will expire on %s." : "Pembagian akan berakhir pada %s.",
    "Cheers!" : "Horee!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hai,<br><br>admin mengaktifkan server-side-encryption. Berkas-berkas Anda dienkripsi menggunakan sandi <strong>%s</strong>.<br><br>Silakan masuk di antarmuka web, pergi ke bagian 'modul enkripsi dasar' pada pengaturan pribadi Anda dan perbarui sandi enkripsi Anda dengan memasukkan sandi ini kedalam kolom 'sandi masuk yang lama' dan sandi masuk yang baru.<br><br>",
    "Encrypt the home storage" : "Enkripsi penyimpanan rumah",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Mengaktifkan opsi ini akan mengenkripsi semua berkas yang disimpan pada penyimpanan utama, jika tidak diaktifkan maka hanya berkas pada penyimpanan eksternal saja yang akan dienkripsi.",
    "Enable recovery key" : "Aktifkan kunci pemulihan",
    "Disable recovery key" : "Nonaktifkan kunci pemulihan",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kunci pemulihan adalah kunci enkripsi tambahan yang digunakan untuk mengenkripsi berkas. Kunci pemulihan memungkinkan untuk memulihkan berkas-berkas pengguna ketika pengguna tersebut melupakan sandi mereka.",
    "Recovery key password" : "Sandi kunci pemulihan",
    "Repeat recovery key password" : "Ulangi sandi kunci pemulihan",
    "Change recovery key password:" : "Ubah sandi kunci pemulihan:",
    "Old recovery key password" : "Sandi kunci pemulihan lama",
    "New recovery key password" : "Sandi kunci pemulihan baru",
    "Repeat new recovery key password" : "Ulangi sandi kunci pemulihan baru",
    "Change Password" : "Ubah Sandi",
    "Basic encryption module" : "Modul enkripsi dasar",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikasi Enskripsi telah diaktifkan tetapi kunci tidak diinisialisasi, silakan log-out dan log-in lagi",
    "Your private key password no longer matches your log-in password." : "Sandi kunci private Anda tidak lagi cocok dengan sandi masuk Anda.",
    "Set your old private key password to your current log-in password:" : "Setel sandi kunci private Anda untuk sandi masuk Anda saat ini:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Jika Anda tidak ingat sandi lama, Anda dapat meminta administrator Anda untuk memulihkan berkas.",
    "Old log-in password" : "Sandi masuk yang lama",
    "Current log-in password" : "Sandi masuk saat ini",
    "Update Private Key Password" : "Perbarui Sandi Kunci Private",
    "Enable password recovery:" : "Aktifkan sandi pemulihan:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Mengaktifkan opsi ini memungkinkan Anda untuk mendapatkan kembali akses ke berkas terenkripsi Anda dalam kasus kehilangan sandi",
    "Enabled" : "Diaktifkan",
    "Disabled" : "Dinonaktifkan"
},
"nplurals=1; plural=0;");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/encryption/l10n/id.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Sandi kunci pemuliahan tidak ada",
    "Please repeat the recovery key password" : "Silakan ulangi sandi kunci pemulihan",
    "Repeated recovery key password does not match the provided recovery key password" : "Sandi kunci pemulihan yang diulangi tidak cocok dengan sandi kunci pemulihan yang diberikan",
    "Recovery key successfully enabled" : "Kunci pemulihan berhasil diaktifkan",
    "Could not enable recovery key. Please check your recovery key password!" : "Tidak dapat mengaktifkan kunci pemulihan. Silakan periksa sandi kunci pemulihan Anda!",
    "Recovery key successfully disabled" : "Kunci pemulihan berhasil dinonaktifkan",
    "Could not disable recovery key. Please check your recovery key password!" : "Tidak dapat menonaktifkan kunci pemulihan. Silakan periksa sandi kunci pemulihan Anda!",
    "Missing parameters" : "Parameter salah",
    "Please provide the old recovery password" : "Mohon berikan sandi pemulihan lama",
    "Please provide a new recovery password" : "Mohon berikan sandi pemulihan baru",
    "Please repeat the new recovery password" : "Silakan ulangi sandi pemulihan baru",
    "Password successfully changed." : "Sandi berhasil diubah",
    "Could not change the password. Maybe the old password was not correct." : "Tidak dapat mengubah sandi. Kemungkinan sandi lama yang dimasukkan salah.",
    "Recovery Key disabled" : "Kunci Pemulihan dinonaktifkan",
    "Recovery Key enabled" : "Kunci Pemulihan diaktifkan",
    "Could not enable the recovery key, please try again or contact your administrator" : "Tidak dapat mengaktifkan kunci pemulihan, silakan coba lagi atau hubungi administrator Anda",
    "Could not update the private key password." : "Tidak dapat memperbarui sandi kunci private.",
    "The old password was not correct, please try again." : "Sandi lama salah, mohon coba lagi.",
    "The current log-in password was not correct, please try again." : "Sandi masuk saat ini salah, mohon coba lagi.",
    "Private key password successfully updated." : "Sandi kunci privat berhasil diperbarui.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Anda perlu mengganti kunci enkripsi Anda dari enkripsi lama (ownCloud <= 8.0) ke yang baru. Mohon jalankan 'occ encryption:migrate' atau hubungi administrator Anda",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Kunci privat tidak sah untuk aplikasi enkripsi. Silakan perbarui sandi kunci privat anda pada pengaturan pribadi untuk memulihkan akses ke berkas anda yang dienkripsi.",
    "Encryption app is enabled and ready" : "Apl enkripsi aktif dan siap",
    "Bad Signature" : "Tanda salah",
    "Missing Signature" : "Tanda hilang",
    "one-time password for server-side-encryption" : "Sandi sekali pakai untuk server-side-encryption",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tidak dapat mendekripsi berkas ini, mungkin ini adalah berkas bersama. Silakan meminta pemilik berkas ini untuk membagikan kembali dengan Anda.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Tidak dapat membaca berkas ini, kemungkinan merupakan berkas berbagi. Silakan minta pemilik berkas untuk membagikan ulang kepada Anda.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hai,\n\nadmin mengaktifkan server-side-encryption. Berkas-berkas Anda dienkripsi menggunakan sandi '%s'.\n\nSilakan masuk di antarmuka web, pergi ke bagian 'modul enkripsi dasar' pada pengaturan pribadi Anda dan perbarui sandi enkripsi Anda dengan memasukkan sandi ini kedalam kolom 'sandi masuk yang lama' dan sandi-masuk saat ini.\n\n",
    "The share will expire on %s." : "Pembagian akan berakhir pada %s.",
    "Cheers!" : "Horee!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hai,<br><br>admin mengaktifkan server-side-encryption. Berkas-berkas Anda dienkripsi menggunakan sandi <strong>%s</strong>.<br><br>Silakan masuk di antarmuka web, pergi ke bagian 'modul enkripsi dasar' pada pengaturan pribadi Anda dan perbarui sandi enkripsi Anda dengan memasukkan sandi ini kedalam kolom 'sandi masuk yang lama' dan sandi masuk yang baru.<br><br>",
    "Default encryption module" : "Modul bawaan enkripsi",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikasi enkripsi telah diaktifkan tetapi kunci tidak terinisialisasi, silakan log-out dan log-in lagi",
    "Encrypt the home storage" : "Enkripsi penyimpanan rumah",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Mengaktifkan opsi ini akan mengenkripsi semua berkas yang disimpan pada penyimpanan utama, jika tidak diaktifkan maka hanya berkas pada penyimpanan eksternal saja yang akan dienkripsi.",
    "Enable recovery key" : "Aktifkan kunci pemulihan",
    "Disable recovery key" : "Nonaktifkan kunci pemulihan",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kunci pemulihan adalah kunci enkripsi tambahan yang digunakan untuk mengenkripsi berkas. Kunci pemulihan memungkinkan untuk memulihkan berkas-berkas pengguna ketika pengguna tersebut melupakan sandi mereka.",
    "Recovery key password" : "Sandi kunci pemulihan",
    "Repeat recovery key password" : "Ulangi sandi kunci pemulihan",
    "Change recovery key password:" : "Ubah sandi kunci pemulihan:",
    "Old recovery key password" : "Sandi kunci pemulihan lama",
    "New recovery key password" : "Sandi kunci pemulihan baru",
    "Repeat new recovery key password" : "Ulangi sandi kunci pemulihan baru",
    "Change Password" : "Ubah Sandi",
    "Basic encryption module" : "Modul enkripsi dasar",
    "Your private key password no longer matches your log-in password." : "Sandi kunci private Anda tidak lagi cocok dengan sandi masuk Anda.",
    "Set your old private key password to your current log-in password:" : "Setel sandi kunci private Anda untuk sandi masuk Anda saat ini:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Jika Anda tidak ingat sandi lama, Anda dapat meminta administrator Anda untuk memulihkan berkas.",
    "Old log-in password" : "Sandi masuk yang lama",
    "Current log-in password" : "Sandi masuk saat ini",
    "Update Private Key Password" : "Perbarui Sandi Kunci Private",
    "Enable password recovery:" : "Aktifkan sandi pemulihan:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Mengaktifkan opsi ini memungkinkan Anda untuk mendapatkan kembali akses ke berkas terenkripsi Anda dalam kasus kehilangan sandi",
    "Enabled" : "Diaktifkan",
    "Disabled" : "Dinonaktifkan",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikasi Enskripsi telah diaktifkan tetapi kunci tidak diinisialisasi, silakan log-out dan log-in lagi"
},
"nplurals=1; plural=0;");
